@@ -36,14 +36,24 @@ import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridRow;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridTest;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.StringDOMElementColumn;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.StringDOMElementSingletonColumn;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.grids.GridRenderer;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.grids.impl.BaseGridRendererHelper;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.selections.SelectionExtension;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.selections.impl.BaseCellSelectionManager;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.impl.DefaultGridLayer;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNull;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(LienzoMockitoTestRunner.class)
 public class BaseGridWidgetKeyboardHandlerTest {
@@ -125,6 +135,35 @@ public class BaseGridWidgetKeyboardHandlerTest {
         setupKeyboardOperations();
     }
 
+    @Test
+    public void testDestroyResourcesOnKeyDown() {
+        when(layer.getGridWidgets()).thenReturn(gridWidgets);
+        when(gridWidget1.isSelected()).thenReturn(true);
+        when(event.getNativeKeyCode()).thenReturn(KeyCodes.KEY_RIGHT);
+
+        final StringDOMElementColumn columnWithAdditionalDomElements = mock(StringDOMElementColumn.class);
+        gridWidget1Data.appendColumn(columnWithAdditionalDomElements);
+
+        handler.onKeyDown(event);
+
+        verify(columnWithAdditionalDomElements).destroyResources();
+    }
+
+    @Test
+    public void testDestroyResourcesAndFlushOnKeyDown() {
+        when(layer.getGridWidgets()).thenReturn(gridWidgets);
+        when(gridWidget1.isSelected()).thenReturn(true);
+        when(event.getNativeKeyCode()).thenReturn(KeyCodes.KEY_RIGHT);
+
+        final StringDOMElementSingletonColumn columnWithAdditionalDomElements = mock(StringDOMElementSingletonColumn.class);
+        gridWidget1Data.appendColumn(columnWithAdditionalDomElements);
+
+        handler.onKeyDown(event);
+
+        verify(columnWithAdditionalDomElements).flush();
+        verify(columnWithAdditionalDomElements).destroyResources();
+    }
+
     @Test
     public void noSelectedDecisionTable() {
         handler.onKeyDown(event);
@@ -184,9 +223,9 @@ public class BaseGridWidgetKeyboardHandlerTest {
         when(gridWidget1.isSelected()).thenReturn(true);
         when(event.getNativeKeyCode()).thenReturn(KeyCodes.KEY_DELETE);
 
-        gridWidget1Data.setCell(0,
-                                0,
-                                new BaseGridCellValue<>("hello"));
+        gridWidget1Data.setCellValue(0,
+                                     0,
+                                     new BaseGridCellValue<>("hello"));
         assertEquals("hello",
                      gridWidget1Data.getCell(0,
                                              0).getValue().getValue());
